%define name	boost
%define version	1.30.0
%define release	1mdk
%define packver	%(echo "%{version}" | sed -e "s/\\\./_/g")

## The Boost version numbers follow this algorithm from the FAQ:
#
# The scheme is x.y.z, where x is incremented only for massive
# changes, such as a reorganization of many libraries, y is
# incremented whenever a new library is added, and z is incremented
# for maintenance releases. y and z are reset to 0 if the value to the
# left changes.
#
# Leave the library major to 1. Set the SONAME to that major only. If
# Y increases but break compatibility and X (major) is not increased,
# then shame on them and add a version script to have something like
# libfoo.so.X(BOOST_1.Y) ?
#
# In ideal world, that'd should not happen assuming Y only increases
# with a library is added. This does not mean incompatible changes is
# possible either.
#
# Well, probably defining lib_major to MAJOR.MINOR is better but
# changing too often? In any case, having the libraries SONAME set to
# MAJOR.MINOR.PATCHLEVEL is not nice, hence Patch1 to provide a way to
# override the actual DSO soname.
%define lib_major		1
%define lib_name_orig		%mklibname boost
%define lib_name		%{lib_name_orig}%{lib_major}

%define build_debug		0
%{expand: %{?_with_DEBUG:       %%define build_debug 1}}
%{expand: %{?_without_DEBUG:    %%define build_debug 0}}

Summary:	Portable C++ libraries.
Name:		%{name}
Version:	%{version}
Release:	%{release}
License:	BSD
Group:		Development/C++
Source:		%{name}_%{packver}.tar.bz2
Patch0:		boost_1_30_0-soname.patch.bz2
URL:		http://boost.org/
Buildroot:	%{_tmppath}/%{name}-%{version}
BuildRequires:	boost-jam >= 3.1

%description
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains only the shared libraries
needed for running programs using Boost.

%package -n %{lib_name}
Summary:	The shared libraries needed for running programs using Boost
Group:		System/Libraries
Provides:	%{lib_name_orig} = %{version}-%{release}
Provides:	%{name} = %{version}-%{release}
Obsoletes:	libboost1.29
%if !%{build_debug}
Obsoletes:	%{lib_name}-debug
Obsoletes:	%{lib_name}-debug-devel
%endif

%description -n %{lib_name}
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains only the shared libraries
needed for running programs dynamically linked against Boost.

%package -n %{lib_name}-devel
Summary:	The libraries and headers needed for Boost development
Group:		Development/C++
Requires:	%{lib_name} = %{version}-%{release}
Provides:	%{lib_name_orig}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	libboost1.29-devel
# It's natural to have documentation and headers in -devel package
Obsoletes:	%{lib_name}-headers, libboost1.29-headers
Provides:	%{lib_name}-headers = %{version}-%{release}
Provides:	%{lib_name_orig}-headers = %{version}-%{release}
Provides:	%{name}-headers = %{version}-%{release}
Obsoletes:	%{lib_name}-doc, libboost1.29-doc
Provides:	%{lib_name}-doc = %{version}-%{release}
Provides:	%{lib_name_orig}-doc = %{version}-%{release}
Provides:	%{name}-doc = %{version}-%{release}

%description -n %{lib_name}-devel
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains documentation, headers and
shared library symlinks needed for Boost development.

%package -n %{lib_name}-static-devel
Summary:	Static libraries for Boost development
Group:		Development/C++
Requires:	%{lib_name}-devel = %{version}-%{release}
Provides:	%{lib_name_orig}-static-devel = %{version}-%{release}
Provides:	%{name}-static-devel = %{version}-%{release}

%description -n %{lib_name}-static-devel
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains only the static libraries
needed for Boost development.

%package -n %{lib_name}-debug
Summary:	The shared libraries needed for running programs using Boost in debug mode
Group:		System/Libraries
Provides:	%{lib_name_orig}-debug = %{version}-%{release}
Provides:	%{name}-debug = %{version}-%{release}
Conflicts:	%{name} < 1.29.0-2payn

%description -n %{lib_name}-debug
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains only the shared libraries
needed for running programs dynamically linked with the debug version
of Boost. Note that many uses of Boost need only the headers, and will
not require these libraries.

%package -n %{lib_name}-debug-devel
Summary:	The libraries needed for Boost debugging
Group:		Development/C++
Provides:	%{lib_name_orig}-debug-devel = %{version}-%{release}
Provides:	%{name}-debug-devel = %{version}-%{release}
Requires:	%{name} = %{version}-%{release}
Requires:	%{name}-headers = %{version}-%{release}
Requires:	%{name}-devel = %{version}-%{release}
Requires:	%{name}-debug = %{version}-%{release}
Conflicts:	%{name}-devel < 1.29.0-2payn
Requires:	%{lib_name}-debug = %{version}-%{release}

%description -n %{lib_name}-debug-devel
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains only the static libraries and
shared library symlinks needed for debugging programs developed with
Boost. Note that many uses of Boost need only the headers, and will
not require these libraries.

# Examples package
%package -n %{lib_name}-examples
Summary:      The examples for the Boost libraries
Group:        Development/C++
Provides:     %{lib_name_orig}-examples = %{version}-%{release}
Provides:     %{name}-examples = %{version}-%{release}
Obsoletes:    libboost1.29-examples

%description -n %{lib_name}-examples
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains examples, installed in the
same place as the documentation.

%prep
%setup -q -n boost_%{packver}
%patch0 -p1 -b .soname

# Preparing the docs
[[ -d doc ]] || mkdir doc
set +x
cp --parents `find -name "*.html"` doc
cp --parents `find -name "*.htm"` doc
cp --parents `find -name "*.css"` doc
cp --parents `find -name "*.gif"` doc
cp --parents `find -name "*.jpg"` doc
cp --parents `find -name "*.png"` doc
cp --parents `find -name "*README*"` doc
set -x

# Preparing the examples: All .hpp or .cpp files that are not in
# directories called test, src, or tools, as well as all files of any
# type in directories called example or examples.
mkdir examples
set +x
cp --parents `find libs -name "*.?pp" ! -path "*test*" ! -path "*src*" ! -path "*tools*" -o -path "*example*" -type f` examples
find examples -name ".cvsignore" | xargs rm -f
set -x

%build
BUILD=release
%if %{build_debug}
BUILD="$BUILD debug"
%endif

# Building all of the libraries.
# This builds python, thread, signals, regex, and test. We ignore test.
# It does not build graph, because that seems to not work at present.
bjam -sTOOLS=gcc -sPYTHON_ROOT=%{_prefix} -sBUILD="$BUILD" -sDLLVERSION_TAG="%{lib_major}"

%install
rm -rf $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{_includedir}
cp -r boost $RPM_BUILD_ROOT%{_includedir}/

mkdir -p $RPM_BUILD_ROOT%{_libdir}/debug
# Install any library we find
function InstallLibraries() {
  type="$1" libdir="$2"
  for lib in `find . -path "*/$type/*" \( -name "libboost_*.so.%{version}" -o -name "libboost_*.a" \)`; do
    lib_basename=${lib##*/}
    lib_linkname=${lib_basename%%%%.%{version}}
    case $lib in
    *.so.*)
      install -m 755 $lib $libdir/
      ln -sf $lib_linkname.%{lib_major} $libdir/$lib_linkname
      ;;
    *.a)
      install -m 644 $lib $libdir/
      ;;
    esac
  done
  /sbin/ldconfig -n $libdir
}

InstallLibraries "release" $RPM_BUILD_ROOT%{_libdir}
%if %{build_debug}
InstallLibraries "debug"   $RPM_BUILD_ROOT%{_libdir}/debug
export EXCLUDE_FROM_STRIP="%{_libdir}/debug"
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post -n %{lib_name} -p /sbin/ldconfig
%postun -n %{lib_name} -p /sbin/ldconfig

%files -n %{lib_name}
%defattr(-,root,root)
%{_libdir}/libboost_*.so.*

%files -n %{lib_name}-devel
%defattr(-,root,root)
%doc doc/*
%{_libdir}/libboost_*.so
%dir %{_includedir}/boost
%{_includedir}/boost/*

%files -n %{lib_name}-static-devel
%defattr(-,root,root)
%{_libdir}/libboost_*.a

%if %{build_debug}
%files -n %{lib_name}-debug
%defattr(-,root,root)
%{_libdir}/debug/libboost_*.so.*
%endif

%if %{build_debug}
%files -n %{lib_name}-debug-devel
%defattr(-,root,root)
%{_libdir}/debug/libboost_*.a
%{_libdir}/debug/libboost_*.so
%endif

%files -n %{lib_name}-examples
%defattr(-,root,root)
%doc examples/*

%changelog
* Sun Mar 30 2003 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 1.30.0-1mdk
- 1.30.0
- Patch1: Let SONAME be overridable. Currently set it to 1 however
- Merge -headers & -doc into -devel package, add -static-devel for *.a
- Move debug libraries to debug subdir, but stop packaging them for now

* Tue Mar 18 2003 Lenny Cartier <lenny@mandrakesoft.com> 1.29.0-4mdk
- from andi payn <payn@myrealbox.com> :
	- complete the Mandrakization process

* Fri Jan 11 2003 - andi payn <payn@myrealbox.com> 1.29.0-3payn
- add examples

* Fri Jan 11 2003 - andi payn <payn@myrealbox.com> 1.29.0-2payn
- make headers and doc packages noarch
- move debug libraries into -debug and -debug-devel

* Fri Jan 11 2003 - andi payn <payn@myrealbox.com> 1.29.0-1payn
- reorganize packaging to use Mandrake library RPM policy
- move from Development/Language/C++ to Development/C++
- add *.so.1.29 and *.so.1
- add ldconfig post/postun script 

* Fri Jan 10 2003 - payn@myrealbox.com
- update to Boost 1.29.0
- use boost-jam to build libraries

* Fri Jul 20 2001 - gerhard@bigfoot.de
- build Boost.Python as shared library

* Sat Jul 07 2001 - gerhard@bigfoot.de
- update to Boost 1.23.0

* Sun Apr 29 2001 - gerhard@bigfoot.de
- created RPM
